@@ -1,6 +1,6 @@
 package MARC::Moose::Lint::Checker::RulesFile;
 # ABSTRACT: A class to 'lint' biblio record based on a rules file
-$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.37';
+$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.38';
 use Moose;
 use Modern::Perl;
 
@@ -117,10 +117,6 @@ sub _set_file {
                 last if defined $_;
             }
             last unless defined $_;
-            if ( length($_) > 1 ) {
-                s/^ *//;
-                s/ *$//;
-            }
         }
     }
 }
@@ -300,7 +296,7 @@ MARC::Moose::Lint::Checker::RulesFile - A class to 'lint' biblio record based on
 
 =head1 VERSION
 
-version 1.0.37
+version 1.0.38
 
 =head1 DESCRIPTION
 
